==> com.liferay.portal.search-8.0.13-sources.jar: com/liferay/portal/search/internal/query/TermsQueryImpl.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.portal.search.internal.query;

import com.liferay.petra.string.StringBundler;
import com.liferay.portal.search.query.QueryVisitor;
import com.liferay.portal.search.query.TermsQuery;

import java.util.Collections;
import java.util.HashSet;
import java.util.Set;

/**
 * @author Michael C. Han
 */
public class TermsQueryImpl extends BaseQueryImpl implements TermsQuery {

	public TermsQueryImpl(String field) {
		_field = field;
	}

	@Override
	public <T> T accept(QueryVisitor<T> queryVisitor) {
		return queryVisitor.visit(this);
	}

	@Override
	public void addValue(Object value) {
		_values.add(value);
	}

	public void addValues(Object... values) {
		Collections.addAll(_values, values);
	}

	@Override
	public String getField() {
		return _field;
	}

	@Override
	public String[] getValues() {
		return _values.toArray(new String[0]);
	}

	@Override
	public boolean isEmpty() {
		return _values.isEmpty();
	}

	@Override
	public String toString() {
		StringBundler sb = new StringBundler(7);

		sb.append("{(");
		sb.append(_field);
		sb.append("=");
		sb.append(_values);
		sb.append("), ");
		sb.append(super.toString());
		sb.append("}");

		return sb.toString();
	}

	private static final long serialVersionUID = 1L;

	private final String _field;
	private final Set<Object> _values = new HashSet<>();

}

==> com.liferay.portal.search-8.0.34-sources.jar: com/liferay/portal/search/internal/query/TermsQueryImpl.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.portal.search.internal.query;

import com.liferay.petra.string.StringBundler;
import com.liferay.portal.search.query.QueryVisitor;
import com.liferay.portal.search.query.TermsQuery;

import java.util.Collections;
import java.util.HashSet;
import java.util.Set;

/**
 * @author Michael C. Han
 */
public class TermsQueryImpl extends BaseQueryImpl implements TermsQuery {

	public TermsQueryImpl(String field) {
		_field = field;
	}

	@Override
	public <T> T accept(QueryVisitor<T> queryVisitor) {
		return queryVisitor.visit(this);
	}

	@Override
	public void addValue(Object value) {
		_values.add(value);
	}

	@Override
	public void addValues(Object... values) {
		Collections.addAll(_values, values);
	}

	@Override
	public String getField() {
		return _field;
	}

	@Override
	public String[] getValues() {
		return _values.toArray(new String[0]);
	}

	@Override
	public boolean isEmpty() {
		return _values.isEmpty();
	}

	@Override
	public String toString() {
		return StringBundler.concat(
			"{(", _field, "=", _values, "), ", super.toString(), "}");
	}

	private static final long serialVersionUID = 1L;

	private final String _field;
	private final Set<Object> _values = new HashSet<>();

}
